==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/GetContextValueOptions.java <==
package software.amazon.awscdk.core;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.909Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GetContextValueOptions extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.core.GetContextKeyOptions {
    /**
     * The value to return if the context value was not found and a missing context is reported.
     * 
     * This should be a dummy value that should preferably
     * fail during deployment since it represents an invalid state.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Object getDummyValue();

    /**
     * @return a {@link Builder} of {@link GetContextValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link GetContextValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Builder {
        private java.lang.Object dummyValue;
        private java.lang.String provider;
        private java.util.Map<java.lang.String, java.lang.Object> props;

        /**
         * Sets the value of DummyValue
         * @param dummyValue The value to return if the context value was not found and a missing context is reported.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dummyValue(java.lang.Object dummyValue) {
            this.dummyValue = dummyValue;
            return this;
        }

        /**
         * Sets the value of Provider
         * @param provider The context provider to query.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder provider(java.lang.String provider) {
            this.provider = provider;
            return this;
        }

        /**
         * Sets the value of Props
         * @param props Provider-specific properties.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(java.util.Map<java.lang.String, java.lang.Object> props) {
            this.props = props;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GetContextValueOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public GetContextValueOptions build() {
            return new Jsii$Proxy(dummyValue, provider, props);
        }

    }

    /**
     * An implementation for {@link GetContextValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GetContextValueOptions {
        private final java.lang.Object dummyValue;
        private final java.lang.String provider;
        private final java.util.Map<java.lang.String, java.lang.Object> props;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.dummyValue = this.jsiiGet("dummyValue", java.lang.Object.class);
            this.provider = this.jsiiGet("provider", java.lang.String.class);
            this.props = this.jsiiGet("props", java.util.Map.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Object dummyValue, java.lang.String provider, java.util.Map<java.lang.String, java.lang.Object> props) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.dummyValue = java.util.Objects.requireNonNull(dummyValue, "dummyValue is required");
            this.provider = java.util.Objects.requireNonNull(provider, "provider is required");
            this.props = props;
        }

        @Override
        public java.lang.Object getDummyValue() {
            return this.dummyValue;
        }

        @Override
        public java.lang.String getProvider() {
            return this.provider;
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.Object> getProps() {
            return this.props;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("dummyValue", om.valueToTree(this.getDummyValue()));
            obj.set("provider", om.valueToTree(this.getProvider()));
            if (this.getProps() != null) {
                obj.set("props", om.valueToTree(this.getProps()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GetContextValueOptions.Jsii$Proxy that = (GetContextValueOptions.Jsii$Proxy) o;

            if (!dummyValue.equals(that.dummyValue)) return false;
            if (!provider.equals(that.provider)) return false;
            return this.props != null ? this.props.equals(that.props) : that.props == null;
        }

        @Override
        public int hashCode() {
            int result = this.dummyValue.hashCode();
            result = 31 * result + (this.provider.hashCode());
            result = 31 * result + (this.props != null ? this.props.hashCode() : 0);
            return result;
        }

    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/GetContextValueOptions.java <==
package software.amazon.awscdk.core;

/**
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.459Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface GetContextValueOptions extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.core.GetContextKeyOptions {

    /**
     * The value to return if the context value was not found and a missing context is reported.
     * 
     * This should be a dummy value that should preferably
     * fail during deployment since it represents an invalid state.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    java.lang.Object getDummyValue();

    /**
     * @return a {@link Builder} of {@link GetContextValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GetContextValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder {
        private java.lang.Object dummyValue;
        private java.lang.String provider;
        private java.util.Map<java.lang.String, java.lang.Object> props;

        /**
         * Sets the value of DummyValue
         * @param dummyValue The value to return if the context value was not found and a missing context is reported. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder dummyValue(java.lang.Object dummyValue) {
            this.dummyValue = dummyValue;
            return this;
        }

        /**
         * Sets the value of Provider
         * @param provider The context provider to query. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder provider(java.lang.String provider) {
            this.provider = provider;
            return this;
        }

        /**
         * Sets the value of Props
         * @param props Provider-specific properties.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder props(java.util.Map<java.lang.String, java.lang.Object> props) {
            this.props = props;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GetContextValueOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public GetContextValueOptions build() {
            return new Jsii$Proxy(dummyValue, provider, props);
        }
    }

    /**
     * An implementation for {@link GetContextValueOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GetContextValueOptions {
        private final java.lang.Object dummyValue;
        private final java.lang.String provider;
        private final java.util.Map<java.lang.String, java.lang.Object> props;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.dummyValue = this.jsiiGet("dummyValue", java.lang.Object.class);
            this.provider = this.jsiiGet("provider", java.lang.String.class);
            this.props = this.jsiiGet("props", java.util.Map.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.Object dummyValue, java.lang.String provider, java.util.Map<java.lang.String, java.lang.Object> props) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.dummyValue = java.util.Objects.requireNonNull(dummyValue, "dummyValue is required");
            this.provider = java.util.Objects.requireNonNull(provider, "provider is required");
            this.props = props;
        }

        @Override
        public java.lang.Object getDummyValue() {
            return this.dummyValue;
        }

        @Override
        public java.lang.String getProvider() {
            return this.provider;
        }

        @Override
        public java.util.Map<java.lang.String, java.lang.Object> getProps() {
            return this.props;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("dummyValue", om.valueToTree(this.getDummyValue()));
            obj.set("provider", om.valueToTree(this.getProvider()));
            if (this.getProps() != null) {
                obj.set("props", om.valueToTree(this.getProps()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GetContextValueOptions.Jsii$Proxy that = (GetContextValueOptions.Jsii$Proxy) o;

            if (!dummyValue.equals(that.dummyValue)) return false;
            if (!provider.equals(that.provider)) return false;
            return this.props != null ? this.props.equals(that.props) : that.props == null;
        }

        @Override
        public int hashCode() {
            int result = this.dummyValue.hashCode();
            result = 31 * result + (this.provider.hashCode());
            result = 31 * result + (this.props != null ? this.props.hashCode() : 0);
            return result;
        }
    }
}
